<?php
/**
 * Plugin Stats View
 *
 * @package    Plugin Stats View
 * @subpackage PluginStatsViewAdmin Management screen
/*
	Copyright (c) 2016- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$pluginstatsviewadmin = new PluginStatsViewAdmin();

/** ==================================================
 * Management screen
 */
class PluginStatsViewAdmin {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.14
	 */
	public function __construct() {

		add_action( 'admin_menu', array( $this, 'plugin_menu' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_custom_wp_admin_style' ) );
		add_filter( 'plugin_action_links', array( $this, 'settings_link' ), 10, 2 );

	}

	/** ==================================================
	 * Add a "Settings" link to the plugins page
	 *
	 * @param  array  $links  links array.
	 * @param  string $file   file.
	 * @return array  $links  links array.
	 * @since 1.00
	 */
	public function settings_link( $links, $file ) {
		static $this_plugin;
		if ( empty( $this_plugin ) ) {
			$this_plugin = 'plugin-stats-view/pluginstatsview.php';
		}
		if ( $file == $this_plugin ) {
			$links[] = '<a href="' . admin_url( 'options-general.php?page=PluginStatsView' ) . '">' . __( 'Settings' ) . '</a>';
		}
		return $links;
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.01
	 */
	public function plugin_menu() {
		add_options_page( 'PluginStatsView Options', 'Plugin Stats View', 'manage_options', 'PluginStatsView', array( $this, 'plugin_options' ) );
	}

	/** ==================================================
	 * Add Css and Script
	 *
	 * @since 1.01
	 */
	public function load_custom_wp_admin_style() {
		if ( $this->is_my_plugin_screen() ) {
			wp_enqueue_style( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ) . 'css/responsive-tabs.css', array(), '1.4.0' );
			wp_enqueue_style( 'jquery-responsiveTabs-style', plugin_dir_url( __DIR__ ) . 'css/style.css', array(), '1.4.0' );
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ) . 'js/jquery.responsiveTabs.min.js', array(), '1.4.0', false );
			wp_enqueue_script( 'pluginstatsview-js', plugin_dir_url( __DIR__ ) . 'js/jquery.pluginstatsview.admin.js', array( 'jquery' ), '1.00', false );
		}
	}

	/** ==================================================
	 * For only admin style
	 *
	 * @since 1.01
	 */
	private function is_my_plugin_screen() {
		$screen = get_current_screen();
		if ( is_object( $screen ) && 'settings_page_PluginStatsView' == $screen->id ) {
			return true;
		} else {
			return false;
		}
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.01
	 */
	public function plugin_options() {

		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permissions to access this page.' ) );
		}

		$this->options_updated();

		$scriptname = admin_url( 'options-general.php?page=PluginStatsView' );

		?>
		<div class="wrap">
			<h2>PluginStatsView</h2>
			<div id="pluginstatsview-tabs">
				<ul>
				<li><a href="#pluginstatsview-tabs-1"><?php esc_html_e( 'How to use', 'plugin-stats-view' ); ?></a></li>
				<li><a href="#pluginstatsview-tabs-2"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></a></li>
				</ul>
				<div id="pluginstatsview-tabs-1">
					<div class="wrap">
						<h2><?php esc_html_e( 'How to use', 'plugin-stats-view' ); ?></h2>
						<div style="padding:10px;"><?php esc_html_e( 'Please add new Page. Please write a short code in the text field of the Page. Please go in Text mode this task.', 'plugin-stats-view' ); ?></div>

						<div style="padding:10px;">
						<h3><?php esc_html_e( 'Example of short code', 'plugin-stats-view' ); ?></h3>

						<div style="padding: 10px 0px;"><code>[psview slug="plugin-stats-view"]</code></div>
						<div style="padding: 10px 0px;"><code>[psview slug="plugin-stats-view" width="300px" size="small" float="none" icon="60px"]</code></div>

						<h3><?php esc_html_e( 'Description of each attribute.', 'plugin-stats-view' ); ?></h3>

						<li style="margin:10px;"><code>slug</code> <?php esc_html_e( 'Specifies the plugin slug.', 'plugin-stats-view' ); ?></li>
						<li style="margin:10px;"><code>width</code> 
						<?php
						/* translators: width */
						echo esc_html( sprintf( __( 'Same as CSS of %1$s.', 'plugin-stats-view' ), 'width' ) . ' ' . __( 'Default' ) );
						?>
						: <code>width=NULL</code></li>
						<li style="margin:10px;"><code>size</code> 
						<?php
						/* translators: size */
						echo esc_html( sprintf( __( 'Same as CSS of %1$s.', 'plugin-stats-view' ), 'size' ) . ' ' . __( 'Default' ) );
						?>
						: <code>size=NULL</code></li>
						<li style="margin:10px;"><code>float</code> 
						<?php
						/* translators: float */
						echo esc_html( sprintf( __( 'Same as CSS of %1$s.', 'plugin-stats-view' ), 'float' ) . ' ' . __( 'Default' ) );
						?>
						: <code>float="none"</code></li>
						<li style="margin:10px;"><code>icon</code> <?php echo esc_html( __( 'Icon size.', 'plugin-stats-view' ) . ' ' . __( 'Default' ) ); ?>: <code>icon="80px"</code></li>
						<li style="margin:10px;"><code>border</code> 
						<?php
						/* translators: border */
						echo esc_html( sprintf( __( 'Same as CSS of %1$s.', 'plugin-stats-view' ), 'border' ) . ' ' . __( 'Default' ) );
						?>
						: <code>border="#CCC 2px solid"</code></li>
						<li style="margin:10px;"><code>view</code> <?php echo esc_html( __( 'View style. Select normal(Standard display) or simple(Convenient display).', 'plugin-stats-view' ) . ' ' . __( 'Default' ) ); ?>: <code>view="normal"</code></li>
						<li style="margin:10px;"><code>link</code> <?php echo esc_html( __( 'You can specify the link destination of the plug-in name. If not specified, this is the plugin homepage link.', 'plugin-stats-view' ) . ' ' . __( 'Default' ) ); ?>: <code>link=NULL</code></li>

						<h3><?php esc_html_e( 'It will create a cache in one-day intervals for speedup. Please delete the cache if you want to display the most recent data.', 'plugin-stats-view' ); ?></h3>

						<form style="padding:10px;" method="post" action="<?php echo esc_url( $scriptname ); ?>" />
						<?php wp_nonce_field( 'psv_settings', 'pluginstatsview_tabs' ); ?>
							<input type="hidden" name="psview_clear_cash" value="1" />
							<?php submit_button( __( 'Remove Cache', 'plugin-stats-view' ), 'large', 'Submit', false ); ?>
						</form>

						</div>

					</div>
				</div>

				<div id="pluginstatsview-tabs-2">
				<div class="wrap">
				<?php $this->credit(); ?>
				</div>
				</div>

			</div>
		</div>
		<?php
	}

	/** ==================================================
	 * Credit
	 *
	 * @since 1.00
	 */
	private function credit() {

		$plugin_name    = null;
		$plugin_ver_num = null;
		$plugin_path    = plugin_dir_path( __DIR__ );
		$plugin_dir     = untrailingslashit( $plugin_path );
		$slugs          = explode( '/', $plugin_dir );
		$slug           = end( $slugs );
		$files          = scandir( $plugin_dir );
		foreach ( $files as $file ) {
			if ( '.' === $file || '..' === $file || is_dir( $plugin_path . $file ) ) {
				continue;
			} else {
				$exts = explode( '.', $file );
				$ext  = strtolower( end( $exts ) );
				if ( 'php' === $ext ) {
					$plugin_datas = get_file_data(
						$plugin_path . $file,
						array(
							'name'    => 'Plugin Name',
							'version' => 'Version',
						)
					);
					if ( array_key_exists( 'name', $plugin_datas ) && ! empty( $plugin_datas['name'] ) && array_key_exists( 'version', $plugin_datas ) && ! empty( $plugin_datas['version'] ) ) {
						$plugin_name    = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __( 'Version:' ) . ' ' . $plugin_ver_num;
		/* translators: FAQ Link & Slug */
		$faq       = sprintf( esc_html__( 'https://wordpress.org/plugins/%s/faq', '%s' ), $slug );
		$support   = 'https://wordpress.org/support/plugin/' . $slug;
		$review    = 'https://wordpress.org/support/view/plugin-reviews/' . $slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/' . $slug;
		$facebook  = 'https://www.facebook.com/katsushikawamori/';
		$twitter   = 'https://twitter.com/dodesyo312';
		$youtube   = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate    = sprintf( esc_html__( 'https://shop.riverforest-wp.info/donate/', '%s' ), $slug );

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo esc_html( $plugin_version ); ?> | 
		<a style="text-decoration: none;" href="<?php echo esc_url( $faq ); ?>" target="_blank"><?php esc_html_e( 'FAQ' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $support ); ?>" target="_blank"><?php esc_html_e( 'Support Forums' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $review ); ?>" target="_blank"><?php sprintf( esc_html_e( 'Reviews', '%s' ), $slug ); ?></a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo esc_url( $translate ); ?>" target="_blank">
		<?php
		/* translators: Plugin translation link */
		echo sprintf( esc_html__( 'Translations for %s' ), esc_html( $plugin_name ) );
		?>
		</a> | <a style="text-decoration: none;" href="<?php echo esc_url( $facebook ); ?>" target="_blank"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $twitter ); ?>" target="_blank"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $youtube ); ?>" target="_blank"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php sprintf( esc_html_e( 'Please make a donation if you like my work or would like to further the development of this plugin.', '%s' ), $slug ); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo esc_url( $donate ); ?>')"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></button>
		</div>

		<?php

	}

	/** ==================================================
	 * Update wp_options table.
	 *
	 * @since 1.02
	 */
	private function options_updated() {

		if ( ! empty( $_POST ) ) {
			if ( isset( $_POST['pluginstatsview_tabs'] ) && ! empty( $_POST['pluginstatsview_tabs'] ) ) {
				if ( check_admin_referer( 'psv_settings', 'pluginstatsview_tabs' ) ) {
					if ( ! empty( $_POST['psview_clear_cash'] ) ) {
						$del_cash_count = $this->delete_all_cash();
						if ( 0 < $del_cash_count ) {
							echo '<div class="notice notice-success is-dismissible"><ul><li>' . esc_html__( 'Removed the cache.', 'plugin-stats-view' ) . '</li></ul></div>';
						} else {
							echo '<div class="notice notice-error is-dismissible"><ul><li>' . esc_html__( 'No Cache', 'plugin-stats-view' ) . '</li></ul></div>';
						}
					}
				}
			}
		}

	}

	/** ==================================================
	 * Delete all cache
	 *
	 * @return int $del_cash_count(int)
	 * @since 1.02
	 */
	private function delete_all_cash() {

		global $wpdb;
		$search_transients = '%psview_datas_%';
		$del_transients = $wpdb->get_results(
			$wpdb->prepare(
				"
						SELECT	option_name
						FROM	$wpdb->options
						WHERE	option_name LIKE %s
						",
				$search_transients
			)
		);

		$del_cash_count = 0;
		foreach ( $del_transients as $del_transient ) {
			$transient = str_replace( '_transient_', '', $del_transient->option_name );
			$value_del_cash = get_transient( $transient );
			if ( false <> $value_del_cash ) {
				delete_transient( $transient );
				++$del_cash_count;
			}
		}

		return $del_cash_count;

	}

}


